==========
Grimsel
==========

**G**\ene\ **R**\al **I**\ntegrated **M**\odeling environment for the **S**\upply of **E**\lectricity and **L**\ow-temperature heat

* Linear/Quadratic programming framework for the cost-optimization of operation and composition of multi-carrier energy systems
* Based on Pyomo
* Input given as normalized tables
* Focus on modification of model structure and parameter values for the efficient generation of large numbers of model runs.
* Currently relies on CPLEX. Other solvers (compatible with Pyomo) could be added easily, as long as they support quadratic objectives (or as long as no power plants with linear cost supply curves are used).

============
Installation
============

``pip install grimsel``

`<https://pypi.org/project/Grimsel/>`_

=============
Documentation
=============

`<https://grimsel.readthedocs.io/>`_

============
Publications
============
  * \M. C. Soini *et al.*, Does bulk electricity storage assist wind and solar in replacing dispatchable power production?, Energy Economics, `<https://doi.org/10.1016/j.eneco.2019.104495>`_. 
  * \A. Rinaldi *et al.*, Optimised allocation of PV and storage capacity among different consumer types and urban settings: A prospective analysis for Switzerland, Journal of Cleaner Production, `<https://doi.org/10.1016/j.jclepro.2020.120762>`_. 
  * \M. C. Soini *et al.*, Impact of prosumer battery operation on the cost of power supply, Journal of Energy Storage `<https://doi.org/10.1016/j.est.2020.101323>`_. 

